- model
optional binary-response model object of class "glm", "gam", "gbm", "randomForest" or "bart". If this argument is provided, 'obs' and 'pred' will be extracted with mod2obspred. Alternatively, you can input the 'obs' and 'pred' arguments instead of 'model'.
- obs
alternatively to 'model' and together with 'pred', a numeric vector of observed presences (1) and absences (0) of a binary response variable. Alternatively (and if 'pred' is a 'SpatRaster'), a two-column matrix or data frame containing, respectively, the x (longitude) and y (latitude) coordinates of the presence points, in which case the 'obs' vector will be extracted with ptsrast2obspred. This argument is ignored if 'model' is provided.
- pred
alternatively to 'model' and together with 'obs', a vector with the corresponding predicted values of presence probability, habitat suitability, environmental favourability or alike. Must be of the same length and in the same order as 'obs'. Alternatively (and if 'obs' is a set of point coordinates), a 'SpatRaster' map of the predicted values for the entire evaluation region, in which case the 'pred' vector will be extracted with ptsrast2obspred. This argument is ignored if 'model' is provided.
- bin.method
argument to pass to getBins specifying the method for grouping the records into bins within which to compare predicted probability to observed prevalence; type modEvAmethods("getBins") for available options, and see Details for more information.
- n.bins
argument to pass to getBins (default 10) specifying the number of bins to use if bin.method = n.bins or bin.method = quantiles.
- fixed.bin.size
argument to pass to getBins, a logical value (default FALSE) indicating whether to force bins to have (approximately) the same size.
- min.bin.size
argument to pass to getBins specifying the minimum number of records in each bin. The default is 15, the minimum required for accurate comparisons of within-bin proportions (Jovani & Tella 2006, Jimenez-Valverde et al. 2013).
- min.prob.interval
argument to pass to getBins specifying the minimum interval (range) of probability values within each bin. The default is 0.1.
- quantile.type
argument to pass to quantile specifying the algorithm to use if bin.method = "quantiles". The default is 7 (the quantile default in R), but check out other types, e.g. 3 (used by SAS), 6 (used by Minitab and SPSS) or 5 (appropriate for deciles, which correspond to the default n.bins = 10).
- simplif
logical (default FALSE), wheter to perform a faster simplified version returning only the basic statistics.
- verbosity
integer specifying the amount of messages or warnings to display. Defaults to the maximum implemented; lower numbers (down to 0) decrease the number of messages.
- alpha
alpha value for confidence intervals if plot = TRUE.
- plot
logical (default TRUE), whether to produce a plot of the results.
- plot.values
logical (default TRUE), whether to report measure values in the plot.
- values.col
character vector of length 1 or 3 specifying the colour(s) for the values in the plot.
- plot.bin.size
logical (default TRUE), whether to report bin sizes in the plot. Sizes below 15 are coloured red, flagging less meaningful predicted-observed comparisons within bins (Jovani & Tella 2006, Jimenez-Valverde et al. 2013).
- xlab
label for the x axis.
- ylab
label for the y axis.
- na.rm
Logical (default TRUE) indicating whether missing values should be ignored in computations.
- rm.dup
If TRUE and if 'pred' is a SpatRaster and if there are repeated points within the same pixel, a maximum of one point per pixel is used to compute the presences. See examples in ptsrast2obspred. The default is FALSE.
- ...
further arguments to pass to the plot function.